@@ -1,7 +1,8 @@
 import pytest
 
 from dem_stitcher import stitch_dem
-from dem_stitcher.exceptions import DEMNotSupported, NoDEMCoverage
+from dem_stitcher.exceptions import (DEMNotSupported, Incorrect4326Bounds,
+                                     NoDEMCoverage)
 
 
 def test_dem_not_supported():
@@ -21,7 +22,7 @@ def test_no_coverage():
 
 
 def test_bad_extents():
-    with pytest.raises(ValueError):
+    with pytest.raises(Incorrect4326Bounds):
         bounds = [-119, 34, -120, 35]
 
         X, p = stitch_dem(bounds,
